@@ -1,11 +1,13 @@
+from .poor_logging import setup_logging,get_outstr,set_logout,add_outstr
 from .listexternal import print_contents, get_xml_files, get_sample_files, get_contents
 from .indata import get_default_data, get_data
 from .read_mappings import get_mapping,get_all_mappings,get_biocatch_mappings,get_socure_mappings,get_biocatch_mappings
-from .read_mappings import read_to_sas_mappings,get_payfoneverify_mappings
+from .read_mappings import read_to_sas_mappings,get_payfoneverify_mappings,get_mapping_choices,add_mapping
 from .steps import get_steps
 from .ccexception import CustomCallException
-from .targets import set_default_targets, get_targets, get_target, update_target, set_enrich_targets
+from .targets import set_default_targets, get_targets, get_target, add_or_update_target, set_enrich_targets
 from .runsteps import decide_with_json
 from .tosas import convert_to_sas
 from .main import enrich
 from .trial import add_one
+from .generate_id_code import gen_structure
