@@ -180,6 +180,32 @@ def get_biocatch_mappings():
                                'biocatch_out', 'biocatch_to_sas.xml', 'biocatchRespToOde')
 
 
+def get_mapping_choices():
+    all = get_all_mappings()
+    vals = ''
+    for key in all.keys():
+        if str(key).endswith('_out'):
+            continue
+        if len(vals) > 0:
+            vals += ', '
+        vals += key
+    return vals
+
+
+# to_map = {'UniqueId': 'uniqueId', 'username': 'user_name'}
+# from_map = {'score': '_a_score', 'confidence': '_a_confidence', 'reference': '_a_referenceId'}
+# mapping = add_mapping(to_map, from_map, 'custom', False)
+def add_mapping(map_to_enrichment, map_from_enrichment, enrichment_name, include_default=True):
+    retmap = {}
+    if include_default:
+        retmap = get_all_mappings()
+
+    retmap[enrichment_name] = map_to_enrichment
+    retmap[enrichment_name + '_out'] = map_from_enrichment
+
+    return retmap
+
+
 def get_all_mappings():
     global mapping_common_to_SAS
 
@@ -204,3 +230,7 @@ def get_all_mappings():
     retmap.update(mapping_iovation)
     retmap.update(mapping_biocatch)
     return retmap
+
+
+if __name__ == '__main__':
+    print(get_mapping_choices())
